import React, { useState, useEffect } from 'react';
import { useNavigate } from 'react-router-dom';
import { useAuth } from '../contexts/AuthContext';
import { supabase } from '../services/supabase';
import MediaForm from '../components/admin/MediaForm';

const AdminMediaPage = () => {
  const navigate = useNavigate();
  const { user, userProfile, loading: authLoading } = useAuth();
  const [media, setMedia] = useState([]);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState(null);
  const [showForm, setShowForm] = useState(false);

  useEffect(() => {
    console.log('AdminMediaPage mounted, user:', user);
    
    if (!authLoading && !user) {
      console.log('No user, redirecting to login');
      navigate('/login');
      return;
    }

    if (userProfile?.role !== 'admin') {
      console.log('Access denied');
      navigate('/');
      return;
    }

    loadMedia();
  }, [user, userProfile, authLoading, navigate]);

  const loadMedia = async () => {
    try {
      setLoading(true);
      const { data, error } = await supabase
        .from('media')
        .select('*')
        .order('created_at', { ascending: false });

      if (error) throw error;

      setMedia(data || []);
    } catch (err) {
      console.error('Error loading media:', err);
      setError(err.message);
    } finally {
      setLoading(false);
    }
  };

  const handleDelete = async (id) => {
    if (!window.confirm('Вы уверены, что хотите удалить этот медиа-контент?')) {
      return;
    }

    try {
      const { error } = await supabase
        .from('media')
        .delete()
        .eq('id', id);

      if (error) throw error;

      setMedia(media.filter(item => item.id !== id));
    } catch (err) {
      console.error('Error deleting media:', err);
      setError(err.message);
    }
  };

  if (authLoading) {
    return <div className="flex justify-center items-center h-screen">Загрузка...</div>;
  }

  if (!user || userProfile?.role !== 'admin') {
    return null;
  }

  return (
    <div className="container-custom pt-20">
      <div className="flex justify-between items-center mb-8">
        <h1 className="text-3xl font-bold text-campfire-amber">Управление медиа</h1>
        <button
          onClick={() => setShowForm(true)}
          className="btn-primary"
        >
          Добавить медиа
        </button>
      </div>

      {error && (
        <div className="bg-red-500/10 border border-red-500/20 text-red-500 p-4 rounded-lg mb-6">
          {error}
        </div>
      )}

      {loading ? (
        <div className="text-center py-8">Загрузка...</div>
      ) : media.length === 0 ? (
        <div className="text-center py-8 text-campfire-light">
          Медиа-контент не найден
        </div>
      ) : (
        <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6">
          {media.map((item) => (
            <div
              key={`${item.id}-${item.type}`}
              className="bg-campfire-charcoal rounded-lg overflow-hidden border border-campfire-ash/20"
            >
              {item.poster_path && (
                <img
                  src={item.poster_path}
                  alt={item.title}
                  className="w-full h-48 object-cover"
                />
              )}
              <div className="p-4">
                <h3 className="text-xl font-semibold text-campfire-amber mb-2">
                  {item.title}
                </h3>
                <p className="text-campfire-light mb-4">
                  {item.type === 'movie' ? 'Фильм' : 'Сериал'}
                </p>
                <div className="flex justify-end space-x-2">
                  <button
                    onClick={() => handleDelete(item.id)}
                    className="text-red-500 hover:text-red-400"
                  >
                    Удалить
                  </button>
                </div>
              </div>
            </div>
          ))}
        </div>
      )}

      {showForm && (
        <MediaForm
          onClose={() => setShowForm(false)}
          onSuccess={() => {
            setShowForm(false);
            loadMedia();
          }}
        />
      )}
    </div>
  );
};

export default AdminMediaPage;
