import React, { useState, useEffect } from 'react';
import { useParams, Link } from 'react-router-dom';
import { useAuth } from '../contexts/AuthContext';
import { supabase } from '../services/supabase';
import {
  FiEdit,
  FiSettings,
  FiCalendar,
  FiStar,
  FiFilm,
  FiTv,
  FiLogOut,
} from "react-icons/fi";
import ReviewCard from "../components/reviews/ReviewCard";
import RatingChart from "../components/reviews/RatingChart";

const ProfilePage = () => {
  const [profile, setProfile] = useState(null);
  const [reviews, setReviews] = useState([]);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState(null);
  const { username } = useParams();
  const { user } = useAuth();

  useEffect(() => {
    const loadProfile = async () => {
      try {
        setLoading(true);
        setError(null);

        // Получаем профиль по username
        const { data: profileData, error: profileError } = await supabase
          .from('users')
          .select('*')
          .eq('username', username)
          .single();

        if (profileError) throw profileError;
        setProfile(profileData);

        // Получаем отзывы пользователя
        const { data: reviewsData, error: reviewsError } = await supabase
          .from('reviews')
          .select(`
            *,
            media(title, type, poster_url)
          `)
          .eq('user_id', profileData.id)
          .order('created_at', { ascending: false });

        if (reviewsError) throw reviewsError;
        setReviews(reviewsData);
      } catch (err) {
        console.error('Error loading profile:', err);
        setError('Не удалось загрузить профиль');
      } finally {
        setLoading(false);
      }
    };

    loadProfile();
  }, [username]);

  if (loading) {
    return (
      <div className="min-h-screen bg-campfire-dark pt-20">
        <div className="container-custom py-12">
          <div className="flex justify-center items-center h-64">
            <div className="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-campfire-amber"></div>
          </div>
        </div>
      </div>
    );
  }

  if (error) {
    return (
      <div className="min-h-screen bg-campfire-dark pt-20">
        <div className="container-custom py-12">
          <div className="bg-status-error/20 text-status-error p-4 rounded-lg text-center">
            {error}
          </div>
        </div>
      </div>
    );
  }

  if (!profile) {
    return (
      <div className="min-h-screen bg-campfire-dark pt-20">
        <div className="container-custom py-12">
          <div className="text-center">
            <h1 className="text-2xl font-bold text-campfire-light mb-4">
              Профиль не найден
            </h1>
            <Link to="/" className="text-campfire-amber hover:text-campfire-ember">
              Вернуться на главную
            </Link>
          </div>
        </div>
      </div>
    );
  }

  return (
    <div className="min-h-screen bg-campfire-dark pt-20">
      <div className="container-custom py-12">
        <div className="bg-campfire-charcoal rounded-lg shadow-lg border border-campfire-ash/20 p-8">
          <div className="flex items-center gap-6 mb-8">
            <div className="w-24 h-24 rounded-full bg-campfire-ash/20 flex items-center justify-center">
              {profile.profile_picture ? (
                <img
                  src={profile.profile_picture}
                  alt={profile.username}
                  className="w-full h-full rounded-full object-cover"
                />
              ) : (
                <span className="text-3xl text-campfire-amber">
                  {profile.username[0].toUpperCase()}
                </span>
              )}
            </div>
            <div>
              <h1 className="text-2xl font-bold text-campfire-light mb-2">
                {profile.username}
              </h1>
              <p className="text-campfire-ash">
                {profile.is_critic ? 'Критик' : 'Пользователь'}
              </p>
            </div>
          </div>

          <div className="space-y-8">
            <div>
              <h2 className="text-xl font-semibold text-campfire-light mb-4">
                Отзывы
              </h2>
              {reviews.length > 0 ? (
                <div className="space-y-4">
                  {reviews.map((review) => (
                    <div
                      key={review.id}
                      className="bg-campfire-dark rounded-lg p-4 border border-campfire-ash/20"
                    >
                      <div className="flex items-center gap-4 mb-2">
                        <img
                          src={review.media.poster_url}
                          alt={review.media.title}
                          className="w-16 h-24 object-cover rounded"
                        />
                        <div>
                          <Link
                            to={`/media/${review.media_id}`}
                            className="text-lg font-medium text-campfire-light hover:text-campfire-amber"
                          >
                            {review.media.title}
                          </Link>
                          <p className="text-sm text-campfire-ash">
                            {new Date(review.created_at).toLocaleDateString()}
                          </p>
                        </div>
                      </div>
                      <p className="text-campfire-light">{review.content}</p>
                    </div>
                  ))}
                </div>
              ) : (
                <p className="text-campfire-ash">
                  Пользователь еще не оставил ни одного отзыва
                </p>
              )}
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};

export default ProfilePage;
