import axios from 'axios';

const IMDB_API_URL = 'https://imdb.iamidiotareyoutoo.com';
const TMDB_API_KEY = import.meta.env.VITE_TMDB_API_KEY;
const TMDB_BASE_URL = 'https://api.themoviedb.org/3';

export const mediaTypes = {
  MOVIE: 'movie',
  TV: 'series',
  GAME: 'game'
};

function isLocalStorageAvailable() {
  try {
    const testKey = '__test__';
    localStorage.setItem(testKey, testKey);
    localStorage.removeItem(testKey);
    return true;
  } catch (e) {
    return false;
  }
}

async function searchIMDb(query, type = mediaTypes.ALL) {
  try {
    const response = await axios.get(`${IMDB_API_URL}/search`, {
      params: { q: query },
      timeout: 5000 // Добавлен таймаут
    });

    if (!response.data || !Array.isArray(response.data)) {
      return [];
    }

    return response.data
      .filter(item => {
        if (!item) return false;
        return type === mediaTypes.ALL || 
              (item.type && item.type.toLowerCase() === type);
      })
      .map(item => ({
        id: item.imdbID || '',
        title: item.title || 'Unknown',
        poster: item.poster || '',
        rating: Math.min(100, Math.max(0, parseFloat(item.rating || '0') * 10)),
        releaseDate: item.year || 'Unknown',
        type: (item.type || '').toLowerCase()
      }));
  } catch (error) {
    console.error('Error searching IMDb:', error);
    return [];
  }
}

export async function getTrendingMedia(type) {
  try {
    if (!isLocalStorageAvailable()) return [];
    
    const mediaStr = localStorage.getItem('media');
    if (!mediaStr) return [];
    
    const media = JSON.parse(mediaStr);
    if (!Array.isArray(media)) return [];
    
    return media
      .filter(item => item && item.type === type && item.trending === true)
      .slice(0, 10);
  } catch (error) {
    console.error('Error fetching trending media:', error);
    return [];
  }
}

export async function getMediaById(id) {
  try {
    if (!isLocalStorageAvailable()) return null;
    
    const mediaStr = localStorage.getItem('media');
    if (!mediaStr) return null;
    
    const media = JSON.parse(mediaStr);
    if (!Array.isArray(media)) return null;
    
    return media.find(item => item && item.id === id) || null;
  } catch (error) {
    console.error('Error fetching media:', error);
    return null;
  }
}

export const searchMedia = async (query, type = 'movie') => {
  try {
    const response = await fetch(
      `${TMDB_BASE_URL}/search/${type}?api_key=${TMDB_API_KEY}&query=${encodeURIComponent(query)}&language=ru-RU`
    );
    
    if (!response.ok) {
      throw new Error('Failed to fetch from TMDB');
    }
    
    const data = await response.json();
    return data.results.map(item => ({
      title: item.title || item.name,
      description: item.overview,
      poster_url: item.poster_path ? `https://image.tmdb.org/t/p/w500${item.poster_path}` : null,
      release_date: item.release_date || item.first_air_date,
      type: type,
      tmdb_id: item.id,
      rating: item.vote_average
    }));
  } catch (error) {
    console.error('Error searching media:', error);
    throw error;
  }
};

export const getMediaDetails = async (tmdbId, type = 'movie') => {
  try {
    const response = await fetch(
      `${TMDB_BASE_URL}/${type}/${tmdbId}?api_key=${TMDB_API_KEY}&language=ru-RU`
    );
    
    if (!response.ok) {
      throw new Error('Failed to fetch media details');
    }
    
    const data = await response.json();
    return {
      title: data.title || data.name,
      description: data.overview,
      poster_url: data.poster_path ? `https://image.tmdb.org/t/p/w500${data.poster_path}` : null,
      release_date: data.release_date || data.first_air_date,
      type: type,
      tmdb_id: data.id,
      rating: data.vote_average,
      genres: data.genres.map(g => g.name).join(', '),
      runtime: data.runtime || data.episode_run_time?.[0] || null
    };
  } catch (error) {
    console.error('Error fetching media details:', error);
    throw error;
  }
};

export async function addMedia(mediaData) {
  try {
    if (!isLocalStorageAvailable()) {
      throw new Error('Local storage is not available');
    }
    
    if (!mediaData || typeof mediaData !== 'object') {
      throw new Error('Invalid media data');
    }
    
    const mediaStr = localStorage.getItem('media') || '[]';
    const media = JSON.parse(mediaStr);
    if (!Array.isArray(media)) {
      throw new Error('Invalid media data in storage');
    }
    
    const newMedia = {
      ...mediaData,
      id: Date.now().toString(),
      createdAt: new Date().toISOString(),
      trending: Boolean(mediaData.trending),
      rating: Math.min(100, Math.max(0, Number(mediaData.rating) || 0)),
      ratingCount: Math.max(0, Number(mediaData.ratingCount) || 0)
    };
    
    media.push(newMedia);
    localStorage.setItem('media', JSON.stringify(media));
    return newMedia.id;
  } catch (error) {
    console.error('Error adding media:', error);
    throw error;
  }
}

export const validateMediaData = (data) => {
  const errors = [];
  
  if (!data.title?.trim()) {
    errors.push('Название обязательно');
  }
  
  if (!data.type || !Object.values(mediaTypes).includes(data.type)) {
    errors.push('Неверный тип медиа');
  }
  
  if (data.rating && (isNaN(data.rating) || data.rating < 0 || data.rating > 10)) {
    errors.push('Рейтинг должен быть от 0 до 10');
  }
  
  return errors;
};

export const formatMediaData = (data) => {
  return {
    title: data.title?.trim(),
    description: data.description?.trim() || '',
    type: data.type,
    poster_url: data.poster_url?.trim() || null,
    release_date: data.release_date || null,
    rating: data.rating ? parseFloat(data.rating) : null,
    genres: data.genres?.trim() || '',
    runtime: data.runtime ? parseInt(data.runtime) : null
  };
};