import { createClient } from '@supabase/supabase-js';

const supabaseUrl = import.meta.env.VITE_SUPABASE_URL;
const supabaseAnonKey = import.meta.env.VITE_SUPABASE_ANON_KEY;

if (!supabaseUrl || !supabaseAnonKey) {
  throw new Error('Missing Supabase environment variables');
}

export const supabase = createClient(supabaseUrl, supabaseAnonKey);

// Auth functions
export const signUp = async (email, password, username) => {
  try {
    console.log('Начало регистрации:', { email, username });

    // Регистрация пользователя
    const { data: authData, error: authError } = await supabase.auth.signUp({
      email,
      password,
      options: {
        data: {
          username: username
        }
      }
    });

    if (authError) {
      console.error('Ошибка при регистрации пользователя:', authError);
      throw authError;
    }

    console.log('Пользователь создан в auth:', authData);

    // Создание профиля пользователя
    const { data: profileData, error: profileError } = await supabase
      .from('users')
      .insert({
        id: authData.user.id,
        username: username,
        email: email,
        role: 'user',
        is_critic: false,
        created_at: new Date().toISOString()
      })
      .select()
      .single();

    if (profileError) {
      console.error('Ошибка при создании профиля:', profileError);
      // Если не удалось создать профиль, удаляем пользователя
      await supabase.auth.admin.deleteUser(authData.user.id);
      throw profileError;
    }

    console.log('Профиль пользователя создан:', profileData);

    return { user: authData.user, profile: profileData };
  } catch (error) {
    console.error('Ошибка при регистрации:', error);
    throw error;
  }
};

export const signIn = async (email, password) => {
  const { data, error } = await supabase.auth.signInWithPassword({ email, password });
  if (error) throw error;
  return data;
};

export const signOut = async () => {
  const { error } = await supabase.auth.signOut();
  if (error) throw error;
};

export const getCurrentUser = async () => {
  const { data: { user }, error } = await supabase.auth.getUser();
  if (error) throw error;
  return user;
};

// User functions
export const getUserProfile = async (userId) => {
  try {
    const { data, error } = await supabase
      .from('users')
      .select('*')
      .eq('id', userId)
      .single();

    if (error) {
      if (error.code === 'PGRST116') {
        // Если профиль не найден, создаем новый
        const { data: newProfile, error: createError } = await supabase
          .from('users')
          .insert([
            {
              id: userId,
              username: `user_${userId.slice(0, 8)}`,
              role: 'user'
            }
          ])
          .select()
          .single();

        if (createError) throw createError;
        return newProfile;
      }
      throw error;
    }

    return data;
  } catch (error) {
    console.error('Error getting user profile:', error);
    throw error;
  }
};

export const updateUserProfile = async (userId, profileData) => {
  try {
    const { data, error } = await supabase
      .from('users')
      .update(profileData)
      .eq('id', userId)
      .select()
      .single();

    if (error) throw error;
    return data;
  } catch (error) {
    console.error('Error updating user profile:', error);
    throw error;
  }
};

// Media functions
export const createMedia = async (mediaData) => {
  try {
    const { data, error } = await supabase
      .from('media')
      .insert([mediaData])
      .select()
      .single();

    if (error) throw error;
    return data;
  } catch (error) {
    console.error('Error creating media:', error);
    throw error;
  }
};

export const getMediaById = async (id) => {
  try {
    const { data, error } = await supabase
      .from('media')
      .select('*')
      .eq('id', id)
      .single();

    if (error) throw error;
    return data;
  } catch (error) {
    console.error('Error getting media:', error);
    throw error;
  }
};

export const listMedia = async (type = null, page = 1, limit = 20) => {
  try {
    let query = supabase
      .from('media')
      .select('*', { count: 'exact' })
      .order('created_at', { ascending: false });

    if (type) {
      query = query.eq('type', type);
    }

    const { data, error, count } = await query
      .range((page - 1) * limit, page * limit - 1);

    if (error) throw error;

    return {
      data,
      count,
      totalPages: Math.ceil(count / limit)
    };
  } catch (error) {
    console.error('Error listing media:', error);
    throw error;
  }
};

export const updateMedia = async (id, mediaData) => {
  try {
    const { data, error } = await supabase
      .from('media')
      .update(mediaData)
      .eq('id', id)
      .select()
      .single();

    if (error) throw error;
    return data;
  } catch (error) {
    console.error('Error updating media:', error);
    throw error;
  }
};

export const deleteMedia = async (id) => {
  try {
    const { error } = await supabase
      .from('media')
      .delete()
      .eq('id', id);

    if (error) throw error;
  } catch (error) {
    console.error('Error deleting media:', error);
    throw error;
  }
};

// Review functions
export const createReview = async (reviewData) => {
  try {
    const { data, error } = await supabase
      .from('reviews')
      .insert([reviewData])
      .select()
      .single();

    if (error) throw error;
    return data;
  } catch (error) {
    console.error('Error creating review:', error);
    throw error;
  }
};

export const getReviewsByMediaId = async (mediaId) => {
  try {
    const { data, error } = await supabase
      .from('reviews')
      .select(`
        *,
        users (
          id,
          username,
          profile_picture
        )
      `)
      .eq('media_id', mediaId)
      .order('created_at', { ascending: false });

    if (error) throw error;
    return data;
  } catch (error) {
    console.error('Error getting reviews:', error);
    throw error;
  }
};