const TMDB_API_KEY = import.meta.env.VITE_TMDB_API_KEY;
const TMDB_BASE_URL = 'https://api.themoviedb.org/3';
const TMDB_IMAGE_BASE_URL = 'https://image.tmdb.org/t/p';

/**
 * Gets the full URL for a TMDB image
 * @param {string} path - The image path from TMDB
 * @param {string} size - The desired image size (w92, w154, w185, w342, w500, w780, original)
 * @returns {string|null} The complete image URL or null if no path provided
 */
export const getImageUrl = (path, size = 'original') => {
  if (!path) return null;
  return `${TMDB_IMAGE_BASE_URL}/${size}${path}`;
};

/**
 * Fetches media details from TMDB API
 * @param {string} id - The media ID
 * @param {string} type - The media type (movie or tv)
 * @returns {Promise<Object>} The media details
 */
export const fetchMediaDetails = async (id, type) => {
  const response = await fetch(
    `${TMDB_BASE_URL}/${type}/${id}?api_key=${TMDB_API_KEY}&append_to_response=credits,videos,similar,recommendations`
  );
  
  if (!response.ok) {
    throw new Error(`Failed to fetch ${type} details`);
  }
  
  return response.json();
};

/**
 * Searches for media in TMDB
 * @param {string} query - The search query
 * @param {string} type - The media type (movie or tv)
 * @returns {Promise<Object>} The search results
 */
export const searchMedia = async (query, type = 'movie') => {
  const response = await fetch(
    `${TMDB_BASE_URL}/search/${type}?api_key=${TMDB_API_KEY}&query=${encodeURIComponent(query)}`
  );
  
  if (!response.ok) {
    throw new Error('Failed to search media');
  }
  
  return response.json();
};

/**
 * Fetches trending media from TMDB
 * @param {string} type - The media type (movie or tv)
 * @param {string} timeWindow - Time window (day or week)
 * @returns {Promise<Object>} The trending media
 */
export const getTrending = async (type = 'movie', timeWindow = 'week') => {
  const response = await fetch(
    `${TMDB_BASE_URL}/trending/${type}/${timeWindow}?api_key=${TMDB_API_KEY}`
  );
  
  if (!response.ok) {
    throw new Error('Failed to fetch trending media');
  }
  
  return response.json();
};